geowatch.utils.lightning\_ext.callbacks.tensorboard\_plotter module
===================================================================

.. automodule:: geowatch.utils.lightning_ext.callbacks.tensorboard_plotter
   :members:
   :undoc-members:
   :show-inheritance:
